WatchAdvertisementsOptions class

The options to configure the WebBluetoothDevice.watchAdvertisements method.

The only option that this object has right now is signal which can be used to abort watching for advertisements.

Annotations

Constructors

WatchAdvertisementsOptions({AbortSignal signal})
The constructor for the options.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signal AbortSignal
This signal can be used to abort watching later on in the program.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited