web/js/js_unsupported library

Classes

JS
A stub implementation of @JS from dart js to make sure that the code will at least compile for native builds.

Constants

anonymous → const _Anonymous
A stub implementation of @anonymous from dart js to make sure that the code will at least compile for native builds. ignore: library_private_types_in_public_api