anonymous top-level constant

_Anonymous const anonymous

A stub implementation of @anonymous from dart js to make sure that the code will at least compile for native builds. ignore: library_private_types_in_public_api

Implementation

const _Anonymous anonymous = _Anonymous();