allowInterop<F extends Function> abstract method

F allowInterop<F extends Function>(
  1. F f
)

Use JS utils to allow for interop from dart functions into js code.

If for example you want to add an event handler than that handler must be wrapped inside this allowInterop method, otherwise the js API cannot call it.

Implementation

F allowInterop<F extends Function>(final F f);